;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "flx-ido" "20260821.1204"
  "Flx integration for ido."
  '((emacs  "24.1")
    (flx    "0.1")
    (cl-lib "0.3"))
  :url "https://github.com/lewang/flx"
  :commit "dc6e4cec66ab05d536ec2cc6f5f324c019e8f8c0"
  :revdesc "dc6e4cec66ab")
